
# Import Predict class from predict module
#from .predict import Predict
# -> cannot import parent class, why?

# Import Predict_Classif class from predict_classif module
from .predict_classif import Predict_Classif
# Import Predict_Regr class from predict_regr module
from .predict_regr import Predict_Regr

#from .Gaussiandistribution import Gaussian
#from .Binomialdistribution import Binomial