from setuptools import setup

setup(name='predictions_210406',
      version='0.1',
      description='Prediction models for classification and regression',
      packages=['predictions_210406'],
      author = 'John Bunge',
      author_email = 'myemail@somethingsomething.com',
      zip_safe=False)
